# print-color

---

### Installing

```
pip3 install print-color
```

### Requirements

- python 3.5^

### Usage

```
from print_color import print

print("Hello world", tag='success', tag_color='green', color='white')
```

Img

```
print("Error detected", tag='failure', tag_color='red', color='magenta')
```

Img

```
print("Printing in color", color='green', format='underline', background='cyan')
```

Img


